==> ace_5.6.3.orig.tar.gz: ACE_wrappers/TAO/CIAO/performance-tests/Protocols/Sender/Sender_exec.h <==
// $Id: Sender_exec.h 78822 2007-07-09 02:15:07Z sowayaa $

#include "SenderEC.h"
#include "Sender_exec_export.h"
#include "tao/LocalObject.h"

class Custom_Network_Priority_Mapping;

namespace CIDL_SenderImpl
{
  class SENDER_EXEC_Export SenderExec_i :
    public virtual SenderExec,
    public virtual TAO_Local_RefCounted_Object
  {
  public:

    SenderExec_i (void);

    void start (::CORBA::ULong iterations,
                ::CORBA::ULong invocation_rate,
                ::CORBA::Boolean count_missed_end_deadlines,
                ::CORBA::Boolean do_dump_history,
                ::CORBA::Boolean print_missed_invocations,
                ::CORBA::ULong message_size,
                ::CORBA::ULong test_protocol_tag,
                ::CORBA::Boolean print_statistics,
                ::CORBA::ULong number_of_connection_attempts,
                ::CORBA::Boolean enable_diffserv_code_points,
                ::CORBA::Short priority,
                ::Protocols::Sender_Controller::Test_Type test_type);

    void shutdown (void);

    void set_session_context (Components::SessionContext_ptr ctx);

    void ccm_activate (void);

    void ccm_passivate (void);

    void ccm_remove (void);

    void ciao_preactivate (void);

    void ciao_postactivate (void);

  protected:

    SenderExec_Context_var context_;

    CORBA::ORB_var orb_;

  };

  class SENDER_EXEC_Export SenderHomeExec_i :
    public virtual SenderHomeExec,
    public virtual TAO_Local_RefCounted_Object
  {
  public:

    ::Components::EnterpriseComponent_ptr create (void);
  };

  extern "C" SENDER_EXEC_Export ::Components::HomeExecutorBase_ptr
  createSenderHome_Impl (void);
}

==> ace_5.7.7+dfsg.orig.tar.gz: ACE_wrappers/TAO/CIAO/performance-tests/Protocols/Sender/Sender_exec.h <==
// $Id: Sender_exec.h 86021 2009-07-14 12:14:35Z wotte $

#include "SenderEC.h"
#include "Sender_exec_export.h"
#include "tao/LocalObject.h"

class Custom_Network_Priority_Mapping;

namespace CIDL_SenderImpl
{
  class SENDER_EXEC_Export SenderExec_i :
    public virtual ::CIAO_Protocols_Sender_Impl::Sender_Exec,
    public virtual ::CORBA::LocalObject
  {
  public:

    SenderExec_i (void);

    void start (::CORBA::ULong iterations,
                ::CORBA::ULong invocation_rate,
                ::CORBA::Boolean count_missed_end_deadlines,
                ::CORBA::Boolean do_dump_history,
                ::CORBA::Boolean print_missed_invocations,
                ::CORBA::ULong message_size,
                ::CORBA::ULong test_protocol_tag,
                ::CORBA::Boolean print_statistics,
                ::CORBA::ULong number_of_connection_attempts,
                ::CORBA::Boolean enable_diffserv_code_points,
                ::CORBA::Short priority,
                ::Protocols::Sender_Controller::Test_Type test_type);

    void shutdown (void);

    void set_session_context (Components::SessionContext_ptr ctx);

    void ccm_activate (void);

    void ccm_passivate (void);

    void ccm_remove (void);

    void configuration_complete (void);

  protected:
    ::CIAO_Protocols_Sender_Impl::Sender_Exec_Context_var context_;

    CORBA::ORB_var orb_;

  };

  class SENDER_EXEC_Export SenderHomeExec_i :
    public virtual ::CIAO_Protocols_Sender_Impl::SenderHome_Exec,
    public virtual ::CORBA::LocalObject
  {
  public:

    ::Components::EnterpriseComponent_ptr create (void);
  };

  extern "C" SENDER_EXEC_Export ::Components::HomeExecutorBase_ptr
  createSenderHome_Impl (void);
}
